@@ -13,12 +13,10 @@
 #include <TSession>
 #include <TCookieJar>
 #include <TAccessValidator>
-#if QT_VERSION >= 0x050000
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonArray>
 #include <QJsonValue>
-#endif
 
 class TActionView;
 class TAbstractUser;
@@ -79,14 +77,12 @@ protected:
     bool renderXml(const QVariantMap &map);
     bool renderXml(const QVariantList &list);
     bool renderXml(const QStringList &list);
-#if QT_VERSION >= 0x050000
     bool renderJson(const QJsonDocument &document);
     bool renderJson(const QJsonObject &object);
     bool renderJson(const QJsonArray &array);
     bool renderJson(const QVariantMap &map);
     bool renderJson(const QVariantList &list);
     bool renderJson(const QStringList &list);
-#endif
     bool renderErrorResponse(int statusCode);
     void redirect(const QUrl &url, int statusCode = Tf::Found);
     bool sendFile(const QString &filePath, const QByteArray &contentType, const QString &name = QString(), bool autoRemove = false);
